@@ -206,6 +206,13 @@ void DolphinSearchBox::showEvent(QShowEvent* event)
     }
 }
 
+void DolphinSearchBox::hideEvent(QHideEvent* event)
+{
+    Q_UNUSED(event);
+    m_startedSearching = false;
+    m_startSearchTimer->stop();
+}
+
 void DolphinSearchBox::keyReleaseEvent(QKeyEvent* event)
 {
     QWidget::keyReleaseEvent(event);
